# Imputation/SRMI

::: survey_kit.imputation.srmi.SRMI
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
        show_source: false
        members:
            - run

::: survey_kit.imputation.variable.Variable
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
        show_source: false
        

::: survey_kit.imputation.parameters.Parameters
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
        show_source: false


::: survey_kit.imputation.selection.Selection
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
        show_source: false
